@@ -208,7 +208,28 @@ class FargateToSsmstringparameter(
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SSM Interface endpoint will be included in this VPC. Default: - none
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FargateToSsmstringparameter.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                public_api: builtins.bool,
+                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+                container_definition_props: typing.Any = None,
+                ecr_image_version: typing.Optional[builtins.str] = None,
+                ecr_repository_arn: typing.Optional[builtins.str] = None,
+                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
+                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
+                existing_string_parameter_obj: typing.Optional[aws_cdk.aws_ssm.StringParameter] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                fargate_service_props: typing.Any = None,
+                fargate_task_definition_props: typing.Any = None,
+                string_parameter_environment_variable_name: typing.Optional[builtins.str] = None,
+                string_parameter_permissions: typing.Optional[builtins.str] = None,
+                string_parameter_props: typing.Optional[typing.Union[aws_cdk.aws_ssm.StringParameterProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToSsmstringparameterProps(
@@ -231,22 +252,22 @@ class FargateToSsmstringparameter(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="container")
     def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
         return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="service")
     def service(self) -> aws_cdk.aws_ecs.FargateService:
         return typing.cast(aws_cdk.aws_ecs.FargateService, jsii.get(self, "service"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stringParameter")
     def string_parameter(self) -> aws_cdk.aws_ssm.StringParameter:
         return typing.cast(aws_cdk.aws_ssm.StringParameter, jsii.get(self, "stringParameter"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
@@ -317,7 +338,26 @@ class FargateToSsmstringparameterProps:
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
-            type_hints = typing.get_type_hints(FargateToSsmstringparameterProps.__init__)
+            def stub(
+                *,
+                public_api: builtins.bool,
+                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+                container_definition_props: typing.Any = None,
+                ecr_image_version: typing.Optional[builtins.str] = None,
+                ecr_repository_arn: typing.Optional[builtins.str] = None,
+                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
+                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
+                existing_string_parameter_obj: typing.Optional[aws_cdk.aws_ssm.StringParameter] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                fargate_service_props: typing.Any = None,
+                fargate_task_definition_props: typing.Any = None,
+                string_parameter_environment_variable_name: typing.Optional[builtins.str] = None,
+                string_parameter_permissions: typing.Optional[builtins.str] = None,
+                string_parameter_props: typing.Optional[typing.Union[aws_cdk.aws_ssm.StringParameterProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
             check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
             check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
